# Changelog

## 2022.7.24

* Bumped dependecies for development and test
* Moved documentation to https://codes.dilettant.life/docs/sammen
* Moved tracker to https://todo.sr.ht/~sthagen/sammen
* Moved normative source repo to https://git.sr.ht/~sthagen/sammen

## 2021.5.12 (v0.0.1)

* Initial release on PyPI
